@@ -2,8 +2,6 @@
 //
 // Copyright (c) 2001-2004 David Ward
 
-// TODO - there's no real reason to distinguish between groups and nodes here - they're all just boxes to be rendered, with the distinction being at the level of the alphabet manager
-
 #include "../Common/Common.h"
 
 #ifdef _WIN32
@@ -63,6 +61,7 @@ CDasherViewSquare::CDasherViewSquare(CEventHandler *pEventHandler, CSettingsStor
   m_ymap = Cymap((myint)GetLongParameter(LP_MAX_Y));
 
   m_bVisibleRegionValid = false;
+  
 }
 
 CDasherViewSquare::~CDasherViewSquare() {
@@ -92,15 +91,44 @@ void CDasherViewSquare::HandleEvent(Dasher::CEvent *pEvent) {
 void CDasherViewSquare::RenderNodes(CDasherNode *pRoot, myint iRootMin, myint iRootMax, std::vector<CDasherNode *> &vNodeList, std::vector<CDasherNode *> &vDeleteList, myint *iGamePointer) {
   DASHER_ASSERT(pRoot != 0);
 
-  Screen()->Blank();
+  //Screen()->Blank(); //NO NEED FOR BLANK ;D
 
   myint iDasherMinX;
   myint iDasherMinY;
   myint iDasherMaxX;
   myint iDasherMaxY;
   VisibleRegion(iDasherMinX, iDasherMinY, iDasherMaxX, iDasherMaxY);
- 
-  RecursiveRender(pRoot, iRootMin, iRootMax, iDasherMaxX, vNodeList, vDeleteList, iGamePointer, true);
+  
+  screenint iScreenLeft;
+  screenint iScreenTop;
+  screenint iScreenRight;
+  screenint iScreenBottom;
+
+  Dasher2Screen(iRootMax-iRootMin, iRootMin, iScreenLeft, iScreenTop);
+  Dasher2Screen(0, iRootMax, iScreenRight, iScreenBottom);
+  if (iScreenTop<1) iScreenTop=1; //If limit is negative
+  if (iScreenLeft<1) iScreenLeft=1; //If limit is negative
+  if (iScreenBottom>Screen()->GetHeight()) iScreenBottom=Screen()->GetHeight()-1; //If limit is too big
+  if (iScreenRight>Screen()->GetWidth()) iScreenRight=Screen()->GetWidth()-1; //If limit is too big
+
+  
+  if(iRootMin > iDasherMinY)
+    DasherDrawRectangle(iDasherMaxX, iDasherMinY, iDasherMinX, iRootMin, 0, 0, Nodes1, false,true, 1);
+
+  if(iRootMax < iDasherMaxY)
+    DasherDrawRectangle(iDasherMaxX, iRootMax, iDasherMinX, iDasherMaxY, 0, 0, Nodes1, false,true, 1);
+
+  //  Screen()->DrawRectangle(Screen()->GetWidth(),iScreenTop,0,0,0, 0, Nodes1, false,true, 1);
+  //Screen()->DrawRectangle(Screen()->GetWidth(),iScreenBottom,0,Screen()->GetHeight(), 0,0, Nodes1, false,true, 1);
+  
+  //Recursive render cleans this one for us so we have to bother only about a thin line!
+//   Screen()->DrawRectangle(1,Screen()->GetHeight(),0,0, 0, 0, Nodes1, false,true, 1);
+  
+//   Screen()->DrawRectangle(Screen()->GetWidth(),iScreenBottom,iScreenRight,iScreenTop, 0, 4, Nodes1, false,true, 1);
+
+  DasherDrawRectangle(0, iDasherMinY, iDasherMinX, iDasherMaxY, 0, 4, Nodes1, false,true, 1);
+
+  RecursiveRender(pRoot, iRootMin, iRootMax, iDasherMaxX, vNodeList, vDeleteList, iGamePointer,true,iDasherMaxX,0);
 
   // DelayDraw the text nodes
   m_pDelayDraw->Draw(Screen());
@@ -108,8 +136,10 @@ void CDasherViewSquare::RenderNodes(CDasherNode *pRoot, myint iRootMin, myint iR
   Crosshair((myint)GetLongParameter(LP_OX));  // add crosshair
 }
 
+int CDasherViewSquare::RecursiveRender(CDasherNode *pRender, myint y1, myint y2, int mostleft, std::vector<CDasherNode *> &vNodeList, std::vector<CDasherNode *> &vDeleteList, myint *iGamePointer, bool bDraw,myint parent_width,int parent_color) {
+
+  //  std::cout << "Recursive render: " << pRender << " " << y1 << " " << y2 << std::endl;
 
-int CDasherViewSquare::RecursiveRender(CDasherNode *pRender, myint y1, myint y2, int mostleft, std::vector<CDasherNode *> &vNodeList, std::vector<CDasherNode *> &vDeleteList, myint *iGamePointer, bool bDraw) {
   DASHER_ASSERT_VALIDPTR_RW(pRender);
 
   // TODO: We need an overhall of the node creation/deletion logic - make sure that we only maintain the minimum number of nodes which are actually needed.
@@ -117,83 +147,117 @@ int CDasherViewSquare::RecursiveRender(CDasherNode *pRender, myint y1, myint y2,
   // if many nodes are created at once (eg untrained Hiragana)
 
   ++m_iRenderCount;
+ 
+  myint temp_parentwidth=parent_width;
+  //  myint trange = y2 - y1;
+  int temp_parentcolor=parent_color;
 
-  if(bDraw && !RenderNode(pRender->Colour(), y1, y2, mostleft, pRender->m_strDisplayText, pRender->m_bShove) && !(pRender->GetGame())) {
+  // TODO: Pass displayinfo directly here
+  if(bDraw && 
+     !RenderNodeFatherFast(parent_color, y1, y2, mostleft, pRender->GetDisplayInfo()->strDisplayText, pRender->GetDisplayInfo()->bShove,parent_width, pRender->GetDisplayInfo()->bVisible) &&
+     !(pRender->GetFlag(NF_GAME))) {
     vDeleteList.push_back(pRender);
-    pRender->Kill();
+    pRender->SetFlag(NF_ALIVE, false);
     return 0;
   }
   
+  // TODO: too slow?
+  // TODO: use flags more rather than delete/reparent lists
+  // pRender->SetFlag(NF_SUPER, !IsNodeVisible(y1, y2)); 
+  myint iDasherMinX;
+  myint iDasherMinY;
+  myint iDasherMaxX;
+  myint iDasherMaxY;
+  VisibleRegion(iDasherMinX, iDasherMinY, iDasherMaxX, iDasherMaxY);
+  pRender->SetFlag(NF_SUPER, (y1 < iDasherMinY) && (y2 > iDasherMaxY) && ((y2 - y1) > iDasherMaxX));
+ 
+
   if(pRender->ChildCount() == 0) {
+	  RenderNodePartFast(pRender->GetDisplayInfo()->iColour, y1, y2, mostleft, pRender->GetDisplayInfo()->strDisplayText, pRender->GetDisplayInfo()->bShove,y2-y1);
     vNodeList.push_back(pRender);
-    return 0;
+    return 1;  // CHANGED BY IGNAS. I return 1 when the child was rendered and in this case the 
+			   //child was rendered.
   }
 
-  if(pRender->GetGame())
+  if(pRender->GetFlag(NF_GAME))
     *iGamePointer = (y1 + y2) / 2;
   
-  // Render groups
-  RenderGroups(pRender, y1, y2, mostleft);
-
   // Render children  
   int norm = (myint)GetLongParameter(LP_NORMALIZATION);
 
   CDasherNode::ChildMap::const_iterator i;
+  /*//IGNAS. Group rendering is not finished yet.
+  bool print_info=false;
+  if (m_iRenderCount == 1) 
+  {
+        
+	print_info=true;
+	printf("Start depth 1 rendering! norm is %ld\n",norm);
+	myint minX,minY,maxX,maxY;
+	VisibleRegion(minX,minY,maxX,maxY);
+	printf("Dasher minY=%ld maxY=%ld, range is %ld!\n",minY,maxY,y2-y1);
+        printf("Parent is %s, its y1=%ld, and y2=%ld , lBnd =%ld, hBnd=%ld\n",pRender->m_strDisplayText.c_str(),y1,y2,pRender->Lbnd(),pRender->Hbnd());
+  }
+  */
+ //IGNAS
+  myint lasty=y1;
+  
+  
+  int id=-1;
+  //  int lower=-1,upper=-1;
+  temp_parentwidth=y2-y1;
+  if(pRender->GetDisplayInfo()->bVisible)
+    temp_parentcolor=pRender->GetDisplayInfo()->iColour;
+  else
+    temp_parentcolor=parent_color;
+    
   for(i = pRender->GetChildren().begin(); i != pRender->GetChildren().end(); i++) {
+    id++;
     CDasherNode *pChild = *i;
     
     myint Range = y2 - y1;
-    myint newy1 = y1 + (Range * pChild->Lbnd()) / norm;
-    myint newy2 = y1 + (Range * pChild->Hbnd()) / norm;
-    
+    myint newy1 = y1 + (Range * (myint)pChild->Lbnd()) / (myint)norm;/// norm and lbnd are simple ints
+    myint newy2 = y1 + (Range * (myint)pChild->Hbnd()) / (myint)norm;
+
     // FIXME - make the threshold a parameter
     
-    if((newy2 - newy1 > 50) || (pChild->Alive())) {
-      pChild->Alive(true);
-      RecursiveRender(pChild, newy1, newy2, mostleft, vNodeList, vDeleteList, iGamePointer, true);
+    if((newy2 - newy1 > 50) || (pChild->GetFlag(NF_ALIVE))) {
+      pChild->SetFlag(NF_ALIVE, true);
+	  if (RecursiveRender(pChild, newy1, newy2, mostleft, vNodeList, vDeleteList, iGamePointer,true,temp_parentwidth,temp_parentcolor))//,print_info);
+	  {
+		  if ((bDraw)&&(lasty<newy1))   //if child has been drawn then the interval between him and the
+							//last drawn child should be drawn too.
+		  RenderNodePartFast(temp_parentcolor, lasty, newy1, mostleft, pRender->GetDisplayInfo()->strDisplayText, pRender->GetDisplayInfo()->bShove,temp_parentwidth);
+		  lasty=newy2;
+	  }
+	  
     }
-    else if(pRender->GetGame()) {
-      RecursiveRender(pChild, newy1, newy2, mostleft, vNodeList, vDeleteList, iGamePointer, false);
+    else if(pRender->GetFlag(NF_GAME)) 
+	{
+		if (RecursiveRender(pChild, newy1, newy2, mostleft, vNodeList, vDeleteList, iGamePointer,false,temp_parentwidth,temp_parentcolor))
+		{
+			if ((bDraw)&&(lasty<newy1))   //if child has been drawn then the interval between him and the
+							  //last drawn child should be drawn too.
+			  RenderNodePartFast(temp_parentcolor, lasty, newy1, mostleft, pRender->GetDisplayInfo()->strDisplayText, pRender->GetDisplayInfo()->bShove,temp_parentwidth);
+			lasty=newy2;
+		}
+	
     }
-  }
   
+  }
+  if (bDraw)
+  {
+		if (lasty<y2)
+			  RenderNodePartFast(temp_parentcolor, lasty, y2, mostleft, pRender->GetDisplayInfo()->strDisplayText, pRender->GetDisplayInfo()->bShove,temp_parentwidth);
+  
+		if(!(pRender->GetFlag(NF_SUBNODE))) 
+		  RenderNodeOutlineFast(pRender->GetDisplayInfo()->iColour, y1, y2, mostleft, pRender->GetDisplayInfo()->strDisplayText, pRender->GetDisplayInfo()->bShove);
+  }
+
   return 1;
 }
 
-void CDasherViewSquare::RenderGroups(CDasherNode *Render, myint y1, myint y2, int mostleft) {
-  SGroupInfo *pCurrentGroup(Render->m_pBaseGroup);
 
-  while(pCurrentGroup) {
-    RecursiveRenderGroups(pCurrentGroup, Render, y1, y2, mostleft);
-    pCurrentGroup = pCurrentGroup->pNext;
-  }
-}
-
-void CDasherViewSquare::RecursiveRenderGroups(SGroupInfo *pCurrentGroup, CDasherNode *pNode, myint y1, myint y2, int mostleft) {
-  
-  if(pCurrentGroup->bVisible) {
-    myint range = y2 - y1;
-    
-    int lower(pCurrentGroup->iStart);
-    int upper(pCurrentGroup->iEnd);
-    
-    myint lbnd = pNode->Children()[lower]->Lbnd();
-    myint hbnd = pNode->Children()[upper - 1]->Hbnd();
-    
-    myint newy1 = y1 + (range * lbnd) / (int)GetLongParameter(LP_NORMALIZATION);
-    myint newy2 = y1 + (range * hbnd) / (int)GetLongParameter(LP_NORMALIZATION);
-    
-    RenderNode(pCurrentGroup->iColour, newy1, newy2, mostleft, pCurrentGroup->strLabel, true);
-  }
-  
-  // Iterate through child groups
-  SGroupInfo *pCurrentChild(pCurrentGroup->pChild);
-
-  while(pCurrentChild) {
-    RecursiveRenderGroups(pCurrentChild, pNode, y1, y2, mostleft);
-    pCurrentChild = pCurrentChild->pNext;
-  }
-}
 
 
 CDasherViewSquare::Cymap::Cymap(myint iScale) {
@@ -219,6 +283,157 @@ bool CDasherViewSquare::IsNodeVisible(myint y1, myint y2) {
 }
 
 
+int CDasherViewSquare::RenderNodeOutlineFast(const int Color, myint y1, myint y2, int &mostleft, const std::string &sDisplayText, bool bShove) {
+
+  // Commenting because click mode occasionally fails this assert.
+  // I don't know why.  -- cjb.
+  if (!(y2 >= y1)) { return 1; }
+  
+  // TODO - Get sensible limits here (to allow for non-linearities)
+  myint iDasherMinX;
+  myint iDasherMinY;
+  myint iDasherMaxX;
+  myint iDasherMaxY;
+
+  VisibleRegion(iDasherMinX, iDasherMinY, iDasherMaxX, iDasherMaxY);
+
+  screenint iScreenX1;
+  screenint iScreenY1;
+  screenint iScreenX2;
+  screenint iScreenY2;
+  
+  Dasher2Screen(0, std::max(y1, iDasherMinY), iScreenX1, iScreenY1);
+  Dasher2Screen(0, std::min(y2, iDasherMaxY), iScreenX2, iScreenY2);
+
+  Cint32 iHeight = std::max(myint(iScreenY2 - iScreenY1),myint( 0));
+  Cint32 iWidth = std::max(myint(iScreenX2 - iScreenX1),myint( 0));
+
+  if((iHeight <= 1) && (iWidth <= 1))
+    return 0;                   // We're too small to render
+
+  if((y1 > iDasherMaxY) || (y2 < iDasherMinY)){
+    return 0;                   // We're entirely off screen, so don't render.
+  }
+ if(!GetBoolParameter(BP_OUTLINE_MODE))
+	  return 1;
+  myint iDasherSize(y2 - y1);
+
+  // FIXME - get rid of pointless assignment below
+
+  int iTruncation(GetLongParameter(LP_TRUNCATION));     // Trucation farction times 100;
+  //  int iTruncationType(GetLongParameter(LP_TRUNCATIONTYPE));
+
+  if(iTruncation == 0) {        // Regular squares
+    DasherDrawRectangle(std::min(iDasherSize,iDasherMaxX), std::min(y2,iDasherMaxY),0, std::max(y1,iDasherMinY), Color, -1, Nodes1, true,false, 1);
+  }
+  else { 
+    // TODO: Put something back here?
+  }
+
+  return 1;
+}
+
+
+// TODO: Document these functions
+int CDasherViewSquare::RenderNodePartFast(const int Color, myint y1, myint y2, int &mostleft, const std::string &sDisplayText, bool bShove,myint iParentWidth ) {
+
+  // Commenting because click mode occasionally fails this assert.
+  // I don't know why.  -- cjb.
+  if (!(y2 >= y1)) { return 1; }
+
+  // TODO - Get sensible limits here (to allow for non-linearities)
+  myint iDasherMinX;
+  myint iDasherMinY;
+  myint iDasherMaxX;
+  myint iDasherMaxY;
+
+  VisibleRegion(iDasherMinX, iDasherMinY, iDasherMaxX, iDasherMaxY);
+
+  screenint iScreenX1;
+  screenint iScreenY1;
+  screenint iScreenX2;
+  screenint iScreenY2;
+  
+  Dasher2Screen(0, std::max(y1, iDasherMinY), iScreenX1, iScreenY1);
+  Dasher2Screen(0, std::min(y2, iDasherMaxY), iScreenX2, iScreenY2);
+
+  Cint32 iHeight = std::max(myint(iScreenY2 - iScreenY1),myint( 0));
+  Cint32 iWidth = std::max(myint(iScreenX2 - iScreenX1),myint( 0));
+
+  if((iHeight <= 1) && (iWidth <= 1))
+    return 0;                   // We're too small to render
+
+  if((y1 > iDasherMaxY) || (y2 < iDasherMinY)){
+    return 0;                   // We're entirely off screen, so don't render.
+  }
+
+  //  myint iDasherSize(y2 - y1);
+
+  // FIXME - get rid of pointless assignment below
+
+  int iTruncation(GetLongParameter(LP_TRUNCATION));     // Trucation farction times -x100;
+  //  int iTruncationType(GetLongParameter(LP_TRUNCATIONTYPE));
+
+  if(iTruncation == 0) {        // Regular squares
+    DasherDrawRectangle(std::min(iParentWidth,iDasherMaxX), std::min(y2,iDasherMaxY),0, std::max(y1,iDasherMinY), Color, -1, Nodes1, false, true, 1);
+  }
+  else {
+   
+  }
+  return 1;
+}
+
+int CDasherViewSquare::RenderNodeFatherFast(const int parent_color, myint y1, myint y2, int &mostleft, const std::string &sDisplayText, bool bShove,myint iParentWidth, bool bVisible) {
+
+  // Commenting because click mode occasionally fails this assert.
+  // I don't know why.  -- cjb.
+  if (!(y2 >= y1)) { return 1; }
+
+  // TODO - Get sensible limits here (to allow for non-linearities)
+  myint iDasherMinX;
+  myint iDasherMinY;
+  myint iDasherMaxX;
+  myint iDasherMaxY;
+
+  VisibleRegion(iDasherMinX, iDasherMinY, iDasherMaxX, iDasherMaxY);
+
+  screenint iScreenX1;
+  screenint iScreenY1;
+  screenint iScreenX2;
+  screenint iScreenY2;
+  
+  Dasher2Screen(0, std::max(y1, iDasherMinY), iScreenX1, iScreenY1);
+  Dasher2Screen(0, std::min(y2, iDasherMaxY), iScreenX2, iScreenY2);
+
+  Cint32 iHeight = std::max(myint(iScreenY2 - iScreenY1),myint( 0));
+  Cint32 iWidth = std::max(myint(iScreenX2 - iScreenX1),myint( 0));
+
+  if((iHeight <= 1) && (iWidth <= 1))
+    return 0;                   // We're too small to render
+
+  if((y1 > iDasherMaxY) || (y2 < iDasherMinY)){
+    return 0;                   // We're entirely off screen, so don't render.
+  }
+
+  myint iDasherSize(y2 - y1);
+
+  // FIXME - get rid of pointless assignment below
+
+  int iTruncation(GetLongParameter(LP_TRUNCATION));     // Trucation farction times 100;
+  // int iTruncationType(GetLongParameter(LP_TRUNCATIONTYPE));
+
+  if(iTruncation == 0) {        // Regular squares
+    DasherDrawRectangle(std::min(iParentWidth,iDasherMaxX), std::min(y2,iDasherMaxY), std::min(iDasherSize,iDasherMaxX), std::max(y1,iDasherMinY), parent_color, -1, Nodes1, false, true, 1);
+  }
+  else { }
+  myint iDasherAnchorX(iDasherSize);
+  if( sDisplayText.size() > 0 )
+  {  
+	  DasherDrawText(iDasherAnchorX, y1, iDasherAnchorX, y2, sDisplayText, mostleft, bShove);
+  }
+  return 1;
+}
+
 int CDasherViewSquare::RenderNode(const int Color, myint y1, myint y2, int &mostleft, const std::string &sDisplayText, bool bShove) {
 
   // Commenting because click mode occasionally fails this assert.
@@ -241,7 +456,7 @@ int CDasherViewSquare::RenderNode(const int Color, myint y1, myint y2, int &most
   Dasher2Screen(0, std::max(y1, iDasherMinY), iScreenX1, iScreenY1);
   Dasher2Screen(0, std::min(y2, iDasherMaxY), iScreenX2, iScreenY2);
 
-  Cint32 iHeight = std::max(iScreenY2 - iScreenY1, (screenint)0);
+  Cint32 iHeight = std::max(myint(iScreenY2 - iScreenY1),myint( 0));
 
   if(iHeight <= 1)
     return 0;                   // We're too small to render
@@ -255,7 +470,7 @@ int CDasherViewSquare::RenderNode(const int Color, myint y1, myint y2, int &most
   // FIXME - get rid of pointless assignment below
 
   int iTruncation(GetLongParameter(LP_TRUNCATION));     // Trucation farction times 100;
-  int iTruncationType(GetLongParameter(LP_TRUNCATIONTYPE));
+  //  int iTruncationType(GetLongParameter(LP_TRUNCATIONTYPE));
 
   if(iTruncation == 0) {        // Regular squares
     DasherDrawRectangle(std::min(iDasherSize,iDasherMaxX), std::min(y2,iDasherMaxY), 0, std::max(y1,iDasherMinY), Color, -1, Nodes1, GetBoolParameter(BP_OUTLINE_MODE), true, 1);
@@ -561,92 +776,30 @@ void CDasherViewSquare::VisibleRegion( myint &iDasherMinX, myint &iDasherMinY, m
   iDasherMaxY = m_iDasherMaxY;
 }
 
-int CDasherViewSquare::GetCoordinates(unsigned long Time, myint &iDasherX, myint &iDasherY) {
+// void CDasherViewSquare::NewDrawGoTo(myint iDasherMin, myint iDasherMax, bool bActive) {
+//   myint iHeight(iDasherMax - iDasherMin);
 
-  // FIXME - Actually turn autocalibration on and off!
-  // FIXME - AutoCalibrate should use Dasher co-ordinates, not raw mouse co-ordinates?
-  // FIXME - Have I broken this by moving it before the offset is applied?
-  // FIXME - put ymap stuff back in 
-  // FIXME - optimise this
+//   int iColour;
+//   int iWidth;
 
-  int iCoordinateCount(GetCoordinateCount());
+//   if(bActive) {
+//     iColour = 1;
+//     iWidth = 3;
+//   }
+//   else {
+//     iColour = 2;
+//     iWidth = 1;
+//   }
 
-  myint *pCoordinates(new myint[iCoordinateCount]);
+//   CDasherScreen::point p[4];
 
-  int iType(GetInputCoordinates(iCoordinateCount, pCoordinates));
+//   Dasher2Screen( 0, iDasherMin, p[0].x, p[0].y);
+//   Dasher2Screen( iHeight, iDasherMin, p[1].x, p[1].y);
+//   Dasher2Screen( iHeight, iDasherMax, p[2].x, p[2].y);
+//   Dasher2Screen( 0, iDasherMax, p[3].x, p[3].y);
 
-  screenint mousex;
-  screenint mousey;
-
-  if(iCoordinateCount == 1) {
-    mousex = 0;
-    mousey = pCoordinates[0];
-  }
-  else {
-    mousex = pCoordinates[0];
-    mousey = pCoordinates[1];
-  }
-
-  delete[]pCoordinates;
-
-  //  bool autocalibrate = GetBoolParameter(BP_AUTOCALIBRATE);
-  //  if(GetBoolParameter(BP_AUTOCALIBRATE) && (GetStringParameter(SP_INPUT_FILTER) == "Eyetracker Mode")) {
-    //    AutoCalibrate(&mousex, &mousey);
-  //  }
-
-
-  // TODO: Mode probably isn't being used any more
-
-  // Convert the input co-ordinates to dasher co-ordinates
-
-  //  Input2Dasher(mousex, mousey, iDasherX, iDasherY);
-  if(iType == 0)
-    Screen2Dasher(mousex, mousey, iDasherX, iDasherY, false, true );
-  else {
-    iDasherX = mousex;
-    iDasherY = mousey;
-  }
-
-//   m_iDasherXCache = iDasherX;
-//   m_iDasherYCache = iDasherY;
-
-  // Request an update at the calculated co-ordinates
-
-
-  // Cache the Dasher Co-ordinates, so we can use them later for things like drawing the mouse position
-#ifndef WITH_MAEMO
-  // FIXME
-  //  iDasherX = myint(xmap(iDasherX / static_cast < double >(GetLongParameter(LP_MAX_Y))) * GetLongParameter(LP_MAX_Y));
-  // iDasherY = m_ymap.map(iDasherY);
-#endif
-
-  return iType;
-}
-
-void CDasherViewSquare::NewDrawGoTo(myint iDasherMin, myint iDasherMax, bool bActive) {
-  myint iHeight(iDasherMax - iDasherMin);
-
-  int iColour;
-  int iWidth;
-
-  if(bActive) {
-    iColour = 1;
-    iWidth = 3;
-  }
-  else {
-    iColour = 2;
-    iWidth = 1;
-  }
-
-  CDasherScreen::point p[4];
-
-  Dasher2Screen( 0, iDasherMin, p[0].x, p[0].y);
-  Dasher2Screen( iHeight, iDasherMin, p[1].x, p[1].y);
-  Dasher2Screen( iHeight, iDasherMax, p[2].x, p[2].y);
-  Dasher2Screen( 0, iDasherMax, p[3].x, p[3].y);
-
-  Screen()->Polyline(p, 4, iWidth, iColour);
-}
+//   Screen()->Polyline(p, 4, iWidth, iColour);
+// }
 
 void CDasherViewSquare::ChangeScreen(CDasherScreen *NewScreen) {
   CDasherView::ChangeScreen(NewScreen);
